pub fn hash_reader(reader: &mut impl Read) -> Result<String>
Compute the SHA-256 hash of data from any reader as a hex string.
Useful for computing hashes of network streams or other data sources that implement std::io::Read.
std::io::Read